@@ -5,4 +5,4 @@ from gcm.models import Device
 class DeviceForm(forms.ModelForm):
     class Meta:
         model = Device
-        fields = ('dev_id', 'reg_id')
+        fields = ('dev_id', 'reg_id', 'is_active')
